Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1284)

Unified Diff: services/ui/display/platform_screen.h

Issue 2503923003: Demonstrate external-window-mode in mus-demo (Closed)
Patch Set: Determine external window mode in mus-ws based on if a WM is connected Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: services/ui/display/platform_screen.h
diff --git a/services/ui/display/platform_screen.h b/services/ui/display/platform_screen.h
index c266a57ee95adfc706c3baadb29653225479ad9a..776d723dff0d0e8cfd1568c6b47170f057405b7e 100644
--- a/services/ui/display/platform_screen.h
+++ b/services/ui/display/platform_screen.h
@@ -32,10 +32,12 @@ class PlatformScreen {
// Triggers initial display configuration to start. On device this will
// configuration the connected displays. Off device this will create one or
- // more fake displays and pretend to configure them. A non-null |delegate|
- // must be provided that will receive notifications when displays are added,
- // removed or modified.
- virtual void Init(PlatformScreenDelegate* delegate) = 0;
+ // more fake displays and pretend to configure them. In external window mode,
+ // no initial display will be created. A non-null |delegate| must be provided
+ // that will receive notifications when displays are added, removed or
+ // modified.
+ virtual void Init(PlatformScreenDelegate* delegate,
+ bool external_window_mode) = 0;
// Handle requests from the platform to close a display.
virtual void RequestCloseDisplay(int64_t display_id) = 0;

Powered by Google App Engine
This is Rietveld 408576698